@@ -1,8 +1,5 @@
 package POE::Component::Server::DNS;
-{
-  $POE::Component::Server::DNS::VERSION = '0.30';
-}
-
+$POE::Component::Server::DNS::VERSION = '0.32';
 #ABSTRACT: A non-blocking, concurrent DNS server POE component
 
 use strict;
@@ -307,6 +304,7 @@ sub _dns_incoming {
     # Refuse unhandled requests, like an authoritative-only
     #  BIND server would.
     $dnsq->header->rcode('REFUSED');
+    $dnsq->header->qr(1);
     $dnsq->header->aa(0);
     $dnsq->header->ra(0);
     $dnsq->header->ad(0);
@@ -438,10 +436,7 @@ sub _dispatch_log {
 }
 
 package DNS::Driver::SendRecv;
-{
-  $DNS::Driver::SendRecv::VERSION = '0.30';
-}
-
+$DNS::Driver::SendRecv::VERSION = '0.32';
 use strict;
 use POE::Driver;
 use Socket;
@@ -490,10 +485,7 @@ sub flush {
 }
 
 package DNS::Filter::UDPDNS;
-{
-  $DNS::Filter::UDPDNS::VERSION = '0.30';
-}
-
+$DNS::Filter::UDPDNS::VERSION = '0.32';
 use strict;
 use POE::Filter;
 use Socket;
@@ -550,13 +542,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::Server::DNS - A non-blocking, concurrent DNS server POE component
 
 =head1 VERSION
 
-version 0.30
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -772,7 +766,7 @@ Stephan Jauernick <stephan@stejau.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Chris Williams, Jan-Pieter Cornet, Brandon Black, Richard Harman and Stephan Jauernick.
+This software is copyright (c) 2015 by Chris Williams, Jan-Pieter Cornet, Brandon Black, Richard Harman and Stephan Jauernick.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
